==> vegan_2.0-1.zip: vegan/doc/diversity-vegan.R <==
###################################################
### chunk number 1: 
###################################################
#line 43 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
par(mfrow=c(1,1))
options(width=72)
figset <- function() par(mar=c(4,4,1,1)+.1)
options(SweaveHooks = list(fig = figset))
options("prompt" = "R> ", "continue" = "+  ")


###################################################
### chunk number 2: 
###################################################
#line 69 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
library(vegan)
data(BCI)


###################################################
### chunk number 3: 
###################################################
#line 89 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
H <- diversity(BCI)


###################################################
### chunk number 4: 
###################################################
#line 97 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
J <- H/log(specnumber(BCI))


###################################################
### chunk number 5: 
###################################################
#line 124 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
k <- sample(nrow(BCI), 6)
R <- renyi(BCI[k,])


###################################################
### chunk number 6: 
###################################################
#line 132 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
require(lattice, quietly=TRUE)


###################################################
### chunk number 7: 
###################################################
#line 136 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
print(plot(R))


###################################################
### chunk number 8: 
###################################################
#line 148 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
alpha <- fisher.alpha(BCI)


###################################################
### chunk number 9: 
###################################################
#line 185 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
quantile(rowSums(BCI))


###################################################
### chunk number 10: 
###################################################
#line 189 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
Srar <- rarefy(BCI, min(rowSums(BCI)))


###################################################
### chunk number 11: 
###################################################
#line 198 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
S2 <- rarefy(BCI, 2)


###################################################
### chunk number 12: 
###################################################
#line 203 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
all(rank(Srar) == rank(S2))


###################################################
### chunk number 13: 
###################################################
#line 209 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
range(diversity(BCI, "simp") - (S2 -1))


###################################################
### chunk number 14: 
###################################################
#line 272 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
data(dune)
data(dune.taxon)
taxdis <- taxa2dist(dune.taxon, varstep=TRUE)
mod <- taxondive(dune, taxdis)


###################################################
### chunk number 15: 
###################################################
#line 279 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
plot(mod)


###################################################
### chunk number 16: 
###################################################
#line 305 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
tr <- hclust(taxdis, "aver")
mod <- treedive(dune, tr)


###################################################
### chunk number 17: 
###################################################
#line 329 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
k <- sample(nrow(BCI), 1)
fish <- fisherfit(BCI[k,])
fish


###################################################
### chunk number 18: 
###################################################
#line 335 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
plot(fish)


###################################################
### chunk number 19: 
###################################################
#line 351 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
confint(fish)


###################################################
### chunk number 20: 
###################################################
#line 376 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
prestondistr(BCI[k,])


###################################################
### chunk number 21: 
###################################################
#line 408 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
rad <- radfit(BCI[k,])
rad


###################################################
### chunk number 22: 
###################################################
#line 413 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
print(radlattice(rad))


###################################################
### chunk number 23: a
###################################################
#line 477 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
sac <- specaccum(BCI)
plot(sac, ci.type="polygon", ci.col="yellow")


###################################################
### chunk number 24: 
###################################################
#line 482 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
#line 477 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw#from line#482#"
sac <- specaccum(BCI)
plot(sac, ci.type="polygon", ci.col="yellow")
#line 483 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"


###################################################
### chunk number 25: 
###################################################
#line 511 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
ncol(BCI)/mean(specnumber(BCI)) - 1


###################################################
### chunk number 26: 
###################################################
#line 529 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
beta <- vegdist(BCI, binary=TRUE)
mean(beta)


###################################################
### chunk number 27: 
###################################################
#line 538 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
betadiver(help=TRUE)


###################################################
### chunk number 28: 
###################################################
#line 557 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
z <- betadiver(BCI, "z")
quantile(z)


###################################################
### chunk number 29: 
###################################################
#line 569 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
data(dune)
data(dune.env)
z <- betadiver(dune, "z")
mod <- with(dune.env, betadisper(z, Management))
mod


###################################################
### chunk number 30: 
###################################################
#line 577 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
boxplot(mod)


###################################################
### chunk number 31: 
###################################################
#line 638 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
specpool(BCI)


###################################################
### chunk number 32: 
###################################################
#line 644 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
s <- sample(nrow(BCI), 25)
specpool(BCI[s,])


###################################################
### chunk number 33: 
###################################################
#line 657 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
estimateR(BCI[k,])


###################################################
### chunk number 34: 
###################################################
#line 694 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
veiledspec(prestondistr(BCI[k,]))
veiledspec(BCI[k,])


###################################################
### chunk number 35: 
###################################################
#line 709 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
smo <- beals(BCI)


###################################################
### chunk number 36: a
###################################################
#line 716 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
j <- which(colnames(BCI) == "Ceiba.pentandra")
plot(beals(BCI, species=j, include=FALSE), BCI[,j], main="Ceiba pentandra", xlab="Probability of occurrence", ylab="Occurrence")


###################################################
### chunk number 37: 
###################################################
#line 721 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"
#line 716 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw#from line#721#"
j <- which(colnames(BCI) == "Ceiba.pentandra")
plot(beals(BCI, species=j, include=FALSE), BCI[,j], main="Ceiba pentandra", xlab="Probability of occurrence", ylab="Occurrence")
#line 722 "d:/Rcompile/CRANpkg/local/2.12/vegan/inst/doc/diversity-vegan.Rnw"

==> vegan_2.7-2.zip: vegan/doc/diversity-vegan.R <==
### R code from vignette source 'diversity-vegan.Rnw'

###################################################
### code chunk number 1: diversity-vegan.Rnw:21-26
###################################################
par(mfrow=c(1,1))
options(width=55)
figset <- function() par(mar=c(4,4,1,1)+.1)
options(SweaveHooks = list(fig = figset))
options("prompt" = "> ", "continue" = "  ")


###################################################
### code chunk number 2: diversity-vegan.Rnw:58-60
###################################################
library(vegan)
data(BCI)


###################################################
### code chunk number 3: diversity-vegan.Rnw:78-79
###################################################
H <- diversity(BCI)


###################################################
### code chunk number 4: diversity-vegan.Rnw:86-87
###################################################
J <- H/log(specnumber(BCI))


###################################################
### code chunk number 5: diversity-vegan.Rnw:113-115
###################################################
k <- sample(nrow(BCI), 6)
R <- renyi(BCI[k,])


###################################################
### code chunk number 6: diversity-vegan.Rnw:122-123
###################################################
getOption("SweaveHooks")[["fig"]]()
print(plot(R))


###################################################
### code chunk number 7: diversity-vegan.Rnw:134-135
###################################################
alpha <- fisher.alpha(BCI)


###################################################
### code chunk number 8: diversity-vegan.Rnw:171-172
###################################################
quantile(rowSums(BCI))


###################################################
### code chunk number 9: diversity-vegan.Rnw:175-176
###################################################
Srar <- rarefy(BCI, min(rowSums(BCI)))


###################################################
### code chunk number 10: diversity-vegan.Rnw:184-185
###################################################
S2 <- rarefy(BCI, 2)


###################################################
### code chunk number 11: diversity-vegan.Rnw:189-190
###################################################
all(rank(Srar) == rank(S2))


###################################################
### code chunk number 12: diversity-vegan.Rnw:196-197
###################################################
range(diversity(BCI, "simp") - (S2 -1))


###################################################
### code chunk number 13: diversity-vegan.Rnw:260-264
###################################################
data(dune)
data(dune.taxon)
taxdis <- taxa2dist(dune.taxon, varstep=TRUE)
mod <- taxondive(dune, taxdis)


###################################################
### code chunk number 14: diversity-vegan.Rnw:267-268
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(mod)


###################################################
### code chunk number 15: diversity-vegan.Rnw:294-296
###################################################
tr <- hclust(taxdis, "aver")
mod <- treedive(dune, tr)


###################################################
### code chunk number 16: diversity-vegan.Rnw:318-321
###################################################
k <- sample(nrow(BCI), 1)
fish <- fisherfit(BCI[k,])
fish


###################################################
### code chunk number 17: diversity-vegan.Rnw:324-325
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(fish)


###################################################
### code chunk number 18: diversity-vegan.Rnw:353-354
###################################################
prestondistr(BCI[k,])


###################################################
### code chunk number 19: diversity-vegan.Rnw:385-387
###################################################
rad <- radfit(BCI[k,])
rad


###################################################
### code chunk number 20: diversity-vegan.Rnw:390-391
###################################################
getOption("SweaveHooks")[["fig"]]()
print(radlattice(rad))


###################################################
### code chunk number 21: a
###################################################
sac <- specaccum(BCI)
plot(sac, ci.type="polygon", ci.col="yellow")


###################################################
### code chunk number 22: diversity-vegan.Rnw:461-462
###################################################
getOption("SweaveHooks")[["fig"]]()
sac <- specaccum(BCI)
plot(sac, ci.type="polygon", ci.col="yellow")


###################################################
### code chunk number 23: diversity-vegan.Rnw:490-491
###################################################
ncol(BCI)/mean(specnumber(BCI)) - 1


###################################################
### code chunk number 24: diversity-vegan.Rnw:508-510
###################################################
beta <- vegdist(BCI, binary=TRUE)
mean(beta)


###################################################
### code chunk number 25: diversity-vegan.Rnw:517-518
###################################################
betadiver(help=TRUE)


###################################################
### code chunk number 26: diversity-vegan.Rnw:536-538
###################################################
z <- betadiver(BCI, "z")
quantile(z)


###################################################
### code chunk number 27: diversity-vegan.Rnw:548-553
###################################################
data(dune)
data(dune.env)
z <- betadiver(dune, "z")
mod <- with(dune.env, betadisper(z, Management))
mod


###################################################
### code chunk number 28: diversity-vegan.Rnw:556-557
###################################################
getOption("SweaveHooks")[["fig"]]()
boxplot(mod)


###################################################
### code chunk number 29: diversity-vegan.Rnw:668-669
###################################################
specpool(BCI)


###################################################
### code chunk number 30: diversity-vegan.Rnw:674-676
###################################################
s <- sample(nrow(BCI), 25)
specpool(BCI[s,])


###################################################
### code chunk number 31: diversity-vegan.Rnw:687-688
###################################################
estimateR(BCI[k,])


###################################################
### code chunk number 32: diversity-vegan.Rnw:757-759
###################################################
veiledspec(prestondistr(BCI[k,]))
veiledspec(BCI[k,])


###################################################
### code chunk number 33: diversity-vegan.Rnw:773-774
###################################################
smo <- beals(BCI)


###################################################
### code chunk number 34: a
###################################################
j <- which(colnames(BCI) == "Ceiba.pentandra")
plot(beals(BCI, species=j, include=FALSE), BCI[,j],
     ylab="Occurrence", main="Ceiba pentandra",
     xlab="Probability of occurrence")


###################################################
### code chunk number 35: diversity-vegan.Rnw:787-788
###################################################
getOption("SweaveHooks")[["fig"]]()
j <- which(colnames(BCI) == "Ceiba.pentandra")
plot(beals(BCI, species=j, include=FALSE), BCI[,j],
     ylab="Occurrence", main="Ceiba pentandra",
     xlab="Probability of occurrence")
